from decouple import config

JWT_SECRET = config("JWT_SECRET")
GOOGLE_CLIENT_ID = config("GOOGLE_CLIENT_ID")
GOOGLE_CLIENT_SECRET = config("GOOGLE_CLIENT_SECRET")
REDIRECT_URL = config("REDIRECT_URL")
MAIL_USERNAME =config('MAIL_USERNAME')
MAIL_PASSWORD =config('MAIL_PASSWORD')
MAIL_FROM =config('MAIL_FROM')
MAIL_PORT = int(config('MAIL_PORT'))
MAIL_SERVER =config('MAIL_SERVER')
MAIL_FROM_NAME =config('MAIL_FROM_NAME')
TEMPLATE_FOLDER = config('TEMPLATE_FOLDER')
EMAIL_VERIFICATION_TEMPLATE = config('EMAIL_VERIFICATION_TEMPLATE')
PASSWORD_RESET_TEMPLATE = config('PASSWORD_RESET_TEMPLATE')
FILES_BASE_FOLDER = config('FILES_BASE_FOLDER')